package
Version:
v0.5.0
Opens a new window with list of versions in this module.
Published: Aug 1, 2026
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Database struct {
Host string `env:"HOST" required:"true"`
Password string `env:"PASSWORD" sensitive:"true"`
Port int `env:"PORT" default:"5432"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.